summaryrefslogtreecommitdiffstats
path: root/kalarm/pickfileradio.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/pickfileradio.h')
-rw-r--r--kalarm/pickfileradio.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/kalarm/pickfileradio.h b/kalarm/pickfileradio.h
index 5486a8a6..974d5502 100644
--- a/kalarm/pickfileradio.h
+++ b/kalarm/pickfileradio.h
@@ -58,19 +58,19 @@ class PickFileRadio : public RadioButton
* @param parent Button group which is to be the parent object for the radio button.
* @param name The name of this widget.
*/
- PickFileRadio(QPushButton* button, LineEdit* edit, const QString& text, QButtonGroup* parent, const char* name = 0);
+ PickFileRadio(TQPushButton* button, LineEdit* edit, const TQString& text, TQButtonGroup* parent, const char* name = 0);
/** Constructor.
* The init() method must be called before the widget can be used.
* @param text Radio button's text.
* @param parent Button group which is to be the parent object for the radio button.
* @param name The name of this widget.
*/
- PickFileRadio(const QString& text, QButtonGroup* parent, const char* name = 0);
+ PickFileRadio(const TQString& text, TQButtonGroup* parent, const char* name = 0);
/** Initialises the widget.
* @param button Push button to invoke the file picker dialogue.
* @param edit File name edit widget, or null if there is none.
*/
- void init(QPushButton* button, LineEdit* edit = 0);
+ void init(TQPushButton* button, LineEdit* edit = 0);
/** Sets whether the radio button and associated widgets are read-only for the user.
* If read-only, their states cannot be changed by the user.
* @param readOnly True to set the widgets read-only, false to set them read-write.
@@ -79,21 +79,21 @@ class PickFileRadio : public RadioButton
/** Chooses a file, for example by displaying a file selection dialogue.
* This method is called when the push button is clicked - the client
* should not activate a file selection dialogue directly.
* @return Selected file name, or QString::null if no selection made.
*/
- virtual QString pickFile() = 0;
+ virtual TQString pickFile() = 0;
/** Notifies the widget of the currently selected file name.
* This should only be used when no file name edit box is used.
* It should be called to initialise the widget's data, and also any time the file
* name is changed without using the push button.
*/
- void setFile(const QString& file);
+ void setFile(const TQString& file);
/** Returns the currently selected file name. */
- QString file() const;
+ TQString file() const;
/** Returns the associated file name edit widget, or null if none. */
LineEdit* fileEdit() const { return mEdit; }
/** Returns the associated file browse push button. */
- QPushButton* pushButton() const { return mButton; }
+ TQPushButton* pushButton() const { return mButton; }
public slots:
/** Enables or disables the radio button, and adjusts the enabled state of the
@@ -109,10 +109,10 @@ class PickFileRadio : public RadioButton
private:
bool pickFileIfNone();
- QButtonGroup* mGroup; // button group which radio button is in
+ TQButtonGroup* mGroup; // button group which radio button is in
LineEdit* mEdit; // file name edit box, or null if none
- QPushButton* mButton; // push button to pick a file
- QString mFile; // saved file name (if mEdit is null)
+ TQPushButton* mButton; // push button to pick a file
+ TQString mFile; // saved file name (if mEdit is null)
int mLastId; // previous radio button selected
bool mRevertId; // true to revert to the previous radio button selection
};
@@ -79,21 +79,21 @@ class PickFileRadio : public RadioButton
* This method is called when the push button is clicked - the client
* should not activate a file selection dialogue directly.
- * @return Selected file name, or QString::null if no selection made.
+ * @return Selected file name, or TQString::null if no selection made.
*/